@@ -27,7 +27,7 @@ def get_int_key(dictionary: dict):
 
 
 class IntegrityCut(Operation):
-    def __init__(self, name: str = 'IntegrityCut', min_len: int = 6, max_len: int = 40):
+    def __init__(self, name: str = 'IntegrityCut', min_len: int = 6, max_len: int = 40, hard_max: int = 128):
         """
         尽量不在句内拆分, 切分引号啥的
         """
@@ -42,7 +42,8 @@ class IntegrityCut(Operation):
         self.is_short_sentence = cond.IsShortSentence(min_length=min_len)
         self.is_sentence_dash = cond.IsSentenceDash()
         self.is_long_sentence = cond.IsLongSentence(max_length=max_len)
-
+        self.is_max_long = cond.IsLongSentence(max_length=hard_max,
+                                               name='integritycut_hardmax') if hard_max > 0 else self.is_long_sentence
         self.right_quota = Symbols.quotation_right.value + Symbols.s_quota_right.value + \
                            Symbols.s_quota_en.value + Symbols.quotation_en.value
 
@@ -51,6 +52,8 @@ class IntegrityCut(Operation):
         self.back_sentence_start.run(seq)
 
         for idx, _ in enumerate(seq):
+            # if self.is_max_long(seq):
+            #     return
             if self.is_short_sentence(seq):
                 continue
             if seq.i >= end_pos:
@@ -71,7 +74,7 @@ class IntegrityCut(Operation):
 
 
 class IntSentenceCut(Operation):
-    def __init__(self, name: str = 'IntSentenceCut', min_len: int = 6, max_len: int = 40):
+    def __init__(self, name: str = 'IntSentenceCut', min_len: int = 6, max_len: int = 40, hard_max: int = 128):
         """
         句子内部切分
         """
@@ -85,6 +88,9 @@ class IntSentenceCut(Operation):
         self.is_end_symbol = cond.IsEndSymbol().add_and(cond.TokenInWhiteList(reverse=True))
         self.is_next_capital = cond.NextStartWithCapital().add_or(cond.NextStartWithNum())
         self.is_short_sentence = cond.IsShortSentence(min_length=min_len)
+        self.is_long_sentence = cond.IsLongSentence(max_length=max_len)
+        self.is_max_long = cond.IsLongSentence(max_length=hard_max,
+                                               name='intsentencecut_hardmax') if hard_max > 0 else self.is_long_sentence
 
         self.is_right_quota = cond.IsRightQuota().add_or(cond.IsRightSingleQuota())
         self.is_blank = cond.IsBlank()
@@ -117,12 +123,19 @@ class IntSentenceCut(Operation):
         split_i = seq.i
         weight = -1000
         n_word = 0
+        hard_max_switch = False
         for idx, _ in enumerate(seq):
             position_penalty = 1 - abs(idx - half_len) / half_len
 
             if seq.i >= end_pos:
                 break
 
+            if self.is_max_long(seq):
+                if weight > max_score:
+                    seq.i = best_i
+                self.cut.run(seq)
+                return
+
             if traverse_trie:
                 score = get_int_key(tree.children)
                 if score is not None:
@@ -171,21 +184,23 @@ class IntSentenceCut(Operation):
             if weight > max_score:
                 best_i = split_i
                 max_score = weight
+
         if best_i > 0:
             seq.i = best_i
             self.cut.run(seq)
 
 
 class LongHandler(Operation):
-    def __init__(self, name: str = 'LongHandler', min_len: int = 6, max_len: int = 40):
+    def __init__(self, name: str = 'LongHandler', min_len: int = 6, max_len: int = 40, hard_max: int = 128):
         super(LongHandler, self).__init__(name)
         # -- set operation -- #
-        self.integrity_cut = IntegrityCut(min_len=min_len, max_len=max_len)
-        self.in_sentence_cut = IntSentenceCut(max_len=max_len, min_len=min_len)
+        self.integrity_cut = IntegrityCut(min_len=min_len, max_len=max_len, hard_max=hard_max)
+        self.in_sentence_cut = IntSentenceCut(max_len=max_len, min_len=min_len, hard_max=hard_max)
         self.cut = opt.Cut()
         # -- set condition -- #
         self.is_long_sentence = cond.IsLongSentence(max_length=max_len)
-
+        self.is_max_long = cond.IsLongSentence(max_length=hard_max,
+                                               name='harmax') if hard_max > 0 else self.is_long_sentence
     def run(self, seq: Sequence) -> None:
         org_i = seq.i
         org_n_word = seq.n_words  # 防止死循环
@@ -195,8 +210,8 @@ class LongHandler(Operation):
             # -- 防止死循环 -- #
             # print(seq.n_words, org_n_word)
             if org_i == seq.i:  # self.is_long_sentence(seq):
-                seq.i += 1
-                seq.n_words += 1
+                # seq.i = org_i
+                seq.n_words = org_n_word
             # print(seq.n_words, org_n_word)
         else:
             return self.cut.run(seq)
